@@ -25,6 +25,7 @@
 #define _stat64		stat
 #define stat64_t	stat
 #define ftruncate64	ftruncate
+#define WAT_DEFAULT_INTERVAL	(-1)
 
 
 struct hostent *
@@ -42,6 +43,13 @@ gethostbyname_r(const char *hostname, struct hostent *dest,
 #define _SOCKLEN_T
 #endif
 
+#define CW_ACTIVE	0
+#define CW_LAST_INVOKE_INTERVAL 60
+#define CW_TH		20
+//#define CW_PITCH	10
+#define CW_INTERVAL	2
+
+
 #endif
 
 
