@@ -24,6 +24,16 @@ extern THREAD_BLOCK *	tb_free_list;
 
 D_SEM	block_lock;
 
+/* Set the mutex kind attribute in *ATTR to KIND (either PTHREAD_MUTEX_NORMAL,                                  
+   PTHREAD_MUTEX_RECURSIVE, PTHREAD_MUTEX_ERRORCHECK, or                                                        
+   PTHREAD_MUTEX_DEFAULT).  */
+extern int pthread_mutexattr_settype (pthread_mutexattr_t *__attr, int __kind)
+     __THROW;
+
+/* Return in *KIND the mutex kind attribute in *ATTR.  */
+extern int pthread_mutexattr_gettype (__const pthread_mutexattr_t *__restrict
+                                      __attr, int *__restrict __kind) __THROW;
+
 
 
 void
@@ -31,10 +41,15 @@ init_thread_block()
 {
 int i;
 D_SEM s;
+pthread_mutexattr_t attr;
+
 	s = &tb[0].sem;
-	sem_init(&s->ss,0,1);
-	sem_trywait(&s->ss);
-	sem_post(&s->ss);
+
+	pthread_mutexattr_init(&attr);
+	pthread_mutexattr_settype(&attr,PTHREAD_MUTEX_ERRORCHECK_NP);
+	pthread_mutex_init(&s->mx,&attr);
+	pthread_mutexattr_destroy(&attr);
+
 	block_lock = s;
 	_lock_task(block_lock,__FILE__,__LINE__);
 	for ( i = 1 ; i < THREAD_BLOCK_SIZE ; i ++ ) {
