@@ -59,6 +59,12 @@ char *strndupa(const char *s, size_t n);
 char *strdup(const char *s);
 */
 
+#define CW_ACTIVE	1
+#define CW_LAST_INVOKE_INTERVAL 60
+#define CW_TH		50
+#define CW_PITCH	10
+#define CW_INTERVAL	2
+
 #endif
 
 
