@@ -20,7 +20,7 @@
 #include	"netutils.h"
 #include	"memory_debug.h"
 
-static char * dm;
+static char * dm_static;
 
 char *
 get_localdomainname()
@@ -28,14 +28,16 @@ get_localdomainname()
 FILE * fd;
 int size;
 char * dmp;
+char * dm;
 	size = 100;
-	if ( dm )
-		return dm;
+	if ( dm_static )
+		return dm_static;
 	fd = fopen("/etc/resolv.conf","r");
 	if ( fd == 0 ) {
 		fprintf(stderr,"get_localdomainname error\n");
 		return 0;
 	}
+	dm = 0;
 	for ( ; ; ) {
 		if ( dm )
 			d_f_ree(dm);
@@ -54,11 +56,12 @@ char * dmp;
 		*dmp = 0;
 		dm = d_re_alloc(dm,strlen(dm)+1);
 		fclose(fd);
+		dm_static = dm;
 		return dm;
 	}
 	if ( dm )
 		d_f_ree(dm);
 	fclose(fd);
-	dm = 0;
+	dm_static = 0;
 	return 0;
 }
