@@ -1,6 +1,6 @@
 /**********************************************************************
  
-	Copyright (C) 2003 Hirohisa MORI <joshua@nichibun.ac.jp>
+	Copyright (C) 2003-2008 Hirohisa MORI <joshua@nichibun.ac.jp>
  
 	This program is free software; you can redistribute it 
 	and/or modify it under the terms of the GLOBALBASE 
@@ -31,6 +31,7 @@
 #include	"machine/fork_lock.h"
 #include	"lock_level.h"
 
+
 typedef void * _TKEY;
 extern int task_flags;
 void ufr_close_all();
@@ -40,6 +41,15 @@ void (*thread_init_func)(int);
 int sigint_handler_glue();
 
 
+int cw_active = CW_ACTIVE;
+int cw_last_invoke_interval = CW_LAST_INVOKE_INTERVAL;
+int cw_th = CW_TH;
+//int cw_pitch = CW_PITCH;
+int cw_interval = CW_INTERVAL;
+int cw_task_count;
+int cw_th_count;
+INTEGER64 cw_th_time;
+
 #define DTI_LENGTH		10000
 
 #ifndef ___TASK_BLOCK
@@ -67,6 +77,11 @@ typedef struct dti {
 	int			msg2;
 } DTI;
 
+typedef struct create_wait {
+	struct create_wait *	next;
+	INTEGER64		ins_time;
+} CREATE_WAIT;
+
 void aboat_resolve_request_init();
 void init_wd();
 void setup_main_thread();
@@ -84,6 +99,8 @@ extern HTID (*get_tid_ptr)();
 
 int task_cnt;
 
+CREATE_WAIT *	create_wait_head,*create_wait_tail;
+int create_wait_task_active;
 
 extern int pri_table[PRI_MAX];
 
@@ -639,6 +656,7 @@ int er;
 	_lock_task(task_lock,__FILE__,__LINE__);
 	_insert_task_hash(&b);
 	task_cnt ++;
+	cw_task_count ++;
 	_unlock_task(task_lock,"_task_grue",__FILE__,__LINE__);
 	for ( ; ; ) {
 
@@ -659,9 +677,17 @@ int er;
 		b.soft_tid = 0;
 		b.finish_time = get_xltime();
 	re_sleep:
+		cw_task_count --;
+		if ( create_wait_head )
+{
+//printf("_create_wait_task gure ---- wakeup\n");
+			t_wakeup_task((int)create_wait_head,0);
+}
 		t_sleep_task((int)&b,task_lock,0);
 
 		_lock_task(task_lock,__FILE__,__LINE__);
+		cw_task_count ++;
+		
 		switch ( b.cmd ) {
 		case TBC_EXEC:
 			if ( b.soft_tid == 0 )
@@ -670,6 +696,7 @@ int er;
 		case TBC_FINISH:
 			_delete_task_hash(&b);
 			task_cnt --;
+			cw_task_count --;
 			_unlock_task(task_lock,"_task_grue",__FILE__,__LINE__);
 			er = pthread_detach((pthread_t)b.hard_tid.tid);
 			pthread_exit(0);
@@ -681,15 +708,48 @@ int er;
 	}
 }
 
+void
+_create_wait_task()
+{
+INTEGER64 now;
+CREATE_WAIT * cw;
+INTEGER64 last_invoke;
+//printf("_create_wait_task start\n");
+	for ( ; ; ) {
+		now = get_xltime();
+		_lock_task(task_lock,__FILE__,__LINE__);
+		if ( create_wait_head == 0 && now - last_invoke > cw_last_invoke_interval ) {
+			create_wait_task_active = 0;
+			_unlock_task(task_lock,"create_wait_task",__FILE__,__LINE__);
+			break;
+		}
+		for ( cw = create_wait_head ; cw ; cw = cw->next ) {
+			if ( now - cw->ins_time < cw_interval )
+				break;
+//printf("_create_wait_task wakeup %p\n",cw);
+			t_wakeup_task((int)cw,0);
+			cw_th_count ++;
+			cw_th_time = now;
+			last_invoke = now;
+		}
+		_unlock_task(task_lock,"create_wait_task",__FILE__,__LINE__);
+		sleep_sec(1);
+	}
+//printf("_create_wait_task end\n");
+}
+
+
 int 
 xx_create_task(void (*func)(),int data,int pri,char * __f,int __l)
 {
 TASK_BLOCK * b;
 int ret;
 int _ret;
-
+CREATE_WAIT cw, ** cwp;
+int retry_cnt;
 
 	_lock_task(task_lock,__FILE__,__LINE__);
+	retry_cnt = 0;
 retry:
 	b = _get_free_block();
 	if ( b ) {
@@ -705,6 +765,41 @@ retry:
 		t_wakeup_task((int)b,0);
 	}
 	else {
+
+		if ( cw_active == 1 && retry_cnt == 0 && cw_task_count > cw_th_count ) {
+			if ( get_xltime() - cw_th_time > cw_last_invoke_interval ) {
+				cw_th_count --;
+				if ( cw_th_count < cw_task_count )
+					cw_th_count = task_cnt;
+				if ( cw_th_count < cw_th )
+					cw_th_count = cw_th;
+			}
+//printf("wait the create 1 %i %p\n",task_cnt,&cw);
+			cw.next = 0;
+			cw.ins_time = get_xltime();
+			if ( create_wait_head == 0 ) {
+				create_wait_head = create_wait_tail = &cw;
+				if ( create_wait_task_active == 0 ) {
+					create_wait_task_active = 1;
+					_create_task(_create_wait_task,0,0);
+				}
+			}
+			else {
+				create_wait_tail->next = &cw;
+				create_wait_tail = &cw;
+			}
+			t_sleep_task((int)&cw,task_lock,0);
+			_lock_task(task_lock,__FILE__,__LINE__);
+			for ( cwp = &create_wait_head ; *cwp ; cwp = &(*cwp)->next )
+				if ( *cwp == &cw )
+					break;
+			*cwp = cw.next;
+			if ( create_wait_head == 0 )
+				create_wait_tail = 0;
+			retry_cnt = 1;
+//printf("wait the create 2\n");
+			goto retry;
+		}
 		b = malloc(sizeof(*b));
 		ret = b->soft_tid = _get_new_tid();
 		b->data = data;
@@ -716,7 +811,10 @@ retry:
 		_ret = _create_task(_task_grue,(int)b,pri);
 		if ( _ret == ESYS_AGAIN ) {
 			free(b);
+			_unlock_task(task_lock,"create_task",__FILE__,__LINE__);
 			sleep_sec(1);
+			_lock_task(task_lock,__FILE__,__LINE__);
+			retry_cnt = 0;
 			goto retry;
 		}
 	}
@@ -978,3 +1076,17 @@ call_main(int argc,char ** argv,int (*main_ptr)(int,char**))
 	return call_main_arg.ret;
 }
 
+void
+set_create_wait(
+	active,
+	last_invoke_interval,
+	th,
+	interval)
+{
+	cw_active = active;
+	cw_last_invoke_interval = last_invoke_interval;
+	cw_th_count = cw_th = th;
+	cw_interval = interval;
+}
+
+
