@@ -250,6 +250,7 @@ int cnt_nos;
 int gn_tree_node,gn_create,gn_wait;
 L_CHAR *  startline;
 int _startline;
+	ret = 0;
 	id = get_sf_attribute(sf,l_string(std_cm,"id"));
 	err_msg = "matrix id";
 	if ( id == 0  )
@@ -284,6 +285,7 @@ int _startline;
 	_ch = atoi(n_string(std_cm,channel));
 
 
+
 	csv = get_sf_attribute(sf,l_string(std_cm,"csv"));
 	if ( csv ) {
 		startline = get_sf_attribute(sf,l_string(std_cm,"startline"));
@@ -317,6 +319,11 @@ ss_printf("CNT=%i\n",cnt_nos);
 tim = get_xltime();
 }
 
+			ret = xli_break_check(s,10);
+			if ( get_type(ret) == XLT_ERROR )
+				break;
+
+
 			str = car(d1);
 			if ( get_type(str) != XLT_STRING ) {
 				gc_pop(d1,gc_gb_sexp);
@@ -555,7 +562,7 @@ tim = get_xltime();
 		free_fields(fd);
 		d_f_ree(crd);
 	}
-	return 0;
+	return ret;
 error:
 	ret = get_error(
 		s->h.file,
