@@ -32,7 +32,7 @@
 #include	"rcache.h"
 #include	"save_global.h"
 
-
+//#define RESOLVE_ROUTE_PROBE
 
 #define MIN_CACHE_EXPIRE	60
 #define MAX_CACHE_EXPIRE	(30*24*3600)
@@ -1303,6 +1303,9 @@ ss_printf("RR %ls %ls\n",b_start,b_target);
 		get_url2(&u,n->handle2_start);
 		n->h.key = get_server_key(&u,0);
 		free_url(&u);
+#ifdef RESOLVE_ROUTE_PROBE
+ss_printf("RESOLVE_ROUTE-PROBE-1 %p %lli %ls %ls\n",n,(INTEGER64)get_xltime(),n->start,n->target);
+#endif
 		insert_queue(&rr_que1,n,1);
 	}
 	else {
@@ -1329,6 +1332,11 @@ unsigned int now;
 int diff;
 MP_ROUTE * r1, * r2;
 
+
+#ifdef RESOLVE_ROUTE_PROBE
+MP_ROUTE_T * test_n;
+#endif
+
 	que = (SYS_QUEUE *)GET_TKEY(d);
 	key = touch_qkey(que);
 	if ( key == 0 )
@@ -1357,11 +1365,17 @@ MP_ROUTE * r1, * r2;
 			wakeup_task((int)n->route);
 			wakeup_task((int)n);
 			if ( (n->flags & RQT_LOCK_MASK) == RQT_UNLOCK ) {
+#ifdef RESOLVE_ROUTE_PROBE
+ss_printf("RESOLVE_ROUTE-PROBE-2 %p %lli %ls %ls\n",n,(INTEGER64)get_xltime(),n->start,n->target);
+#endif
 				if ( n->route )
 					_flush_route(n->route);
 				free_mp_route_t(n);
 			}
 			if ( r2 == 0 ) {
+#ifdef RESOLVE_ROUTE_PROBE
+ss_printf("RESOLVE_ROUTE-PROBE-3 %p %lli\n",n,(INTEGER64)get_xltime());
+#endif
 				unlock_task(route_lock,"rr_task1");
 				continue;
 			}
@@ -1372,18 +1386,32 @@ MP_ROUTE * r1, * r2;
 			else if ( diff > MAX_CACHE_EXPIRE )
 				diff = MAX_CACHE_EXPIRE;
 			if ( r2->update + diff < now ) {
+#ifdef RESOLVE_ROUTE_PROBE
+test_n = n;
+#endif
 				n = new_mp_route_t(
 					r2->head->url,
 					r2->tail->url,
 					RQT_UNLOCK|RQT_ROUTE);
+#ifdef RESOLVE_ROUTE_PROBE
+ss_printf("RESOLVE_ROUTE-PROBE-4 %p %lli - %p %ls %ls\n",test_n,(INTEGER64)get_xltime(),n,n->start,n->target);
+#endif
 //				r2->sts = RS_LOADING;
 				n->route = r2;
 				n->handle1_start = n->start;
 				n->handle1_target = n->target;
 				n->handle2_start = n->start;
 				n->handle2_target = n->target;
+
+				get_url2(&u,n->handle2_start);
+				n->h.key = get_server_key(&u,0);
+				free_url(&u);
+				
 			}
 			else {
+#ifdef RESOLVE_ROUTE_PROBE
+ss_printf("RESOLVE_ROUTE-PROBE-5 %p %lli\n",n,(INTEGER64)get_xltime());
+#endif
 				_flush_route(r2);
 				/* cache is usable */
 				unlock_task(route_lock,"rr_task1");
@@ -1452,9 +1480,7 @@ int ret;
 	if ( sq_key_cond(q,n,key) == -1 )
 		return -1;
 	ret = check_delay(n->get,(int)q);
-/*
-ss_printf("C %ls %i\n",key,ret);
-*/
+
 	if ( n->route )
 		n->route->w_cond = ret;
 	if ( ret == CDT_WAIT )
@@ -1476,7 +1502,6 @@ L_CHAR * tmp;
 MP_ROUTE * r;
 int flags;
 
-
 	que = (SYS_QUEUE *)GET_TKEY(d);
 	key = touch_qkey(que);
 	if ( key == 0 )
@@ -1496,7 +1521,6 @@ int flags;
 		}
 		n = delete_queue(que,rr_task2_cond,key,1);
 
-
 		rrr_delete(n->handle2_start);
 
 
@@ -1532,6 +1556,9 @@ int flags;
 
 			gc_pop(0,0);
 
+#ifdef RESOLVE_ROUTE_PROBE
+ss_printf("RESOLVE_ROUTE-PROBE-6 %p %lli %ls %ls\n",n,(INTEGER64)get_xltime(),n->start,n->target);
+#endif
 			goto last;
 		}
 		lock_task(route_lock);
@@ -1581,6 +1608,9 @@ ss_printf("ERR RETRY %ls %ls\n",n->handle1_start,n->handle1_target);
 		continue;
 
 	err:
+#ifdef RESOLVE_ROUTE_PROBE
+ss_printf("RESOLVE_ROUTE-PROBE-7 %p %lli %ls %ls\n",n,(INTEGER64)get_xltime(),n->start,n->target);
+#endif
 		flags = n->flags;
 		n->flags |= RQT_ROUTE_ERR;
 		r = n->route;
