@@ -1363,6 +1363,8 @@ MATRIX_SEXP * sd;
 		sd->del = 1;
 	}
 
+	if ( t->h.key )
+		d_f_ree(t->h.key);
 	t->h.key = get_server_key(&ow->r->h.target,0);
 	t->func = 0;
 	t->aboat_func = aboat_old_matrix;
