@@ -36,6 +36,7 @@
 #include	"h_layering.h"
 #include	"xlerror.h"
 #include	"heuristics_win_frame.h"
+#include	"radar.h"
 
 #define CURRENT_SWITCH_TIMERAG	2
 #define ZONBIE_TIMEOUT	120
@@ -43,10 +44,10 @@
 
 void ov_default();
 
-void _wakeup_win_manage(void *);
-void wakeup_win_manage(void *);
+/*
 void _wakeup_loading_task(void);
 void wakeup_loading_task(void *);
+*/
 void min_route_task(void *);
 void _wakeup_min_route_task(void *);
 void wakeup_min_route_task(void *);
@@ -550,7 +551,7 @@ SYMBOL_INDICATE * si;
 }
 
 int
-_win_lock(GBVIEW_FLAME * gf,WIN_FLAME * wf)
+_xx_win_lock(GBVIEW_FLAME * gf,WIN_FLAME * wf,char * __file,int __line)
 {
 int id;
 WF_LOCK_LIST * wfl;
@@ -566,6 +567,8 @@ retry:
 		wfl = d_alloc(sizeof(*wfl));
 		wfl->next = wf->lock_list;
 		wfl->tid = get_tid();
+		wfl->file_name = __file;
+		wfl->line_no = __line;
 		wf->lock_list  = wfl;
 	}
 	else {
@@ -583,7 +586,7 @@ retry:
 }
 
 int
-_win_wlock(GBVIEW_FLAME * gf,WIN_FLAME * wf)
+_xx_win_wlock(GBVIEW_FLAME * gf,WIN_FLAME * wf,char * __file,int __line)
 {
 int id;
 WF_LOCK_LIST * wfl;
@@ -601,6 +604,8 @@ WF_LOCK_LIST * wfl;
 	wfl = d_alloc(sizeof(*wfl));
 	wfl->next = wf->lock_list;
 	wfl->tid = get_tid();
+	wfl->file_name = __file;
+	wfl->line_no = __line;
 	wf->lock_list  = wfl;
 
 	_wakeup_at_redraw_wp(gf);
@@ -2359,6 +2364,9 @@ VRECT rr;
 	wf_unlock(gf);
 	assert_ls(gf,LSF_ZOOM);
 	_set_move_timer(gf);
+#ifdef CACHE_TEST_DEBUG
+ss_printf("CACHE-TEST WAKEUP-WIN-MANAGE %lli\n",(INTEGER64)get_xltime());
+#endif
 	_wakeup_win_manage(gf->radar_ptr);
 
 	if ( p ) {
@@ -3170,6 +3178,9 @@ end1:
 	assert_ls(gf,LSF_ZOOM);
 	gf->move_flag = 1;
 	_set_move_timer(gf);
+#ifdef CACHE_TEST_DEBUG
+ss_printf("CACHE-TEST WAKEUP-WIN-MANAGE %lli\n",(INTEGER64)get_xltime());
+#endif
 	_wakeup_win_manage(gf->radar_ptr);
 	wf_unlock(gf);
 end:
