@@ -70,6 +70,7 @@ int smap_waiting_time;
 void gc_mp_task_t(MP_TASK_T * t);
 void gc_get_mp_task_t(MP_TASK_T * t);
 
+int mp_live_stop_mode;
 
 void
 smap_count_up(int time_all);
@@ -176,6 +177,16 @@ int i;
 	insert_tick_que(20,0,TQT_LGC,TQL_NORMAL);
 }
 
+void
+wait_que_stable()
+{
+int i;
+	wait_queue_total_cnt(&mp_task_que,0,WQF_EQU);
+	for ( i = 0 ; i < GRUE_2_NOS ; i ++ )
+		wait_queue_total_cnt(&mp_task_que_2[i],0,WQF_EQU);
+}
+
+
 MP_TASK_T *
 new_mp_task_t()
 {
@@ -306,6 +317,24 @@ free_mp_task_t(MP_TASK_T * tt)
 	unlock_task(tick_que_lock_2,"free_mp_task_t");
 }
 
+typedef struct pri_key {
+	L_CHAR *	key;
+	int		pri;
+} PRI_KEY;
+
+int
+sq_pri_key_cond(SYS_QUEUE * q,void * n,void * work)
+{
+PRI_KEY * pk;
+Q_HEADER *_n;
+	pk = (PRI_KEY*)work;
+	_n = (Q_HEADER*)n;
+	if ( pk->pri != _n->pri )
+		return -1;
+	return sq_key_cond(q,n,pk->key);
+}
+
+
 void
 mp_task_que_grue()
 {
@@ -314,7 +343,7 @@ L_CHAR * key;
 L_CHAR * key_copy;
 XL_INTERPRETER * xli;
 MP_TASK_ENV e;
-
+PRI_KEY pk;
 
 	key = touch_qkey(&mp_task_que);
 	if ( key == 0 )
@@ -333,12 +362,20 @@ MP_TASK_ENV e;
 
 	for ( ; ; ) {
 		gc_push(0,0,"mp_task_que_grue");
-		tt = delete_queue(&mp_task_que,sq_key_cond,key,0);
+		pk.key = key;
+		pk.pri = 0;
+		for ( ; pk.pri < TQL_MAX ; pk.pri ++ ) {
+			tt = delete_queue(&mp_task_que,sq_pri_key_cond,(void*)&pk,0);
+			if ( tt )
+				break;
+		}
 		if ( tt == 0 ) {
 		 	gc_pop(0,0);
 			break;
 		}
-		(*tt->op)(&e,tt);
+		if ( mp_live_stop_mode == 0 )
+			(*tt->op)(&e,tt);
+		else	free_mp_task_t(tt);
 		gc_pop(0,0);
 	}
 
@@ -405,7 +442,9 @@ SYS_QUEUE * q;
 		 	gc_pop(0,0);
 			break;
 		}
-		(*tt->op)(&e,tt);
+		if ( mp_live_stop_mode == 0 )
+			(*tt->op)(&e,tt);
+		else	free_mp_task_t(tt);
 		gc_pop(0,0);
 	}
 
@@ -425,6 +464,7 @@ char buf[100];
 AVT_NODE *a1,* a2;
 int i;
 int cnt,_cnt,_i;
+MP_TASK_T * tt2;
 
 	_i = 0;
 	_cnt = 0x7fffffff;
@@ -457,6 +497,9 @@ int cnt,_cnt,_i;
 			insert_queue(&mp_task_que,tt,1);
 		}
 		else {
+			tt2 = a2->data;
+			if ( tt2->h.pri > tt->h.pri )
+				tt2->h.pri = tt->h.pri;
 			d_f_ree(a1);
 			_free_mp_task_t(tt,0);
 			unlock_task(tick_que_lock_2,"insert_mp_task_que");
@@ -526,16 +569,53 @@ printf("idle %i %i\n",t - get_xltime(),idle_interval);
 
 
 int
-mp_live()
+mp_live(int live_type)
 {
+int ret;
+static int mp_live_flag;
+static int exit_cpu;
 
-	if ( startup_time == 0 )
-		return 0;
-	if ( get_xltime() - startup_time < MP_LIVE_MAX )
-		return 0;
-	exit_stabilizer('r');
+	lock_task(tick_que_lock);
+	if ( mp_live_flag ) {
+		if ( live_type == 0 ) {
+			exit_cpu ++;
+			wakeup_task((int)&exit_cpu);
+		}
+		ret = -1;
+		goto end;
+	}
+	if ( live_type == 1 )
+		goto force_exit;
+	if ( startup_time == 0 ) {
+		ret = 0;
+		goto end;
+	}
+	if ( get_xltime() - startup_time < MP_LIVE_MAX ) {
+		ret = 0;
+		goto end;
+	}
+force_exit:
+	mp_live_flag = 1;
+	mp_live_stop_mode = 1;
+	if ( live_type == 0 ) {
+		exit_cpu ++;
+		wakeup_task((int)&exit_cpu);
+	}
+	for ( ; exit_cpu < cpu_nos ; ) {
+		sleep_task((int)&exit_cpu,tick_que_lock);
+		lock_task(tick_que_lock);
+	}
+	unlock_task(tick_que_lock,"mp_live");
+
+	wait_que_stable();
+	if ( live_type == 0 )
+		exit_stabilizer('r');
+	else	exit_stabilizer('e');
 	u_exit(0);
-	return 0;
+	ret = 0;
+end:
+	unlock_task(tick_que_lock,"mp_live");
+	return ret;;
 }
 
 void
@@ -908,6 +988,7 @@ int tim;
 void
 tqt_lmp_op(MP_TASK_ENV * e,MP_TASK_T * tt)
 {
+
 	check_my_lump(e->ses,tt->tq->filename);
 	free_mp_task_t(tt);
 }
@@ -1089,19 +1170,15 @@ MP_TASK_T * tt;
 		}
 		if ( t1 == 0 ) {
 
-			if ( mp_live() )
+			if ( mp_live(0) )
 				return;
 
 			sleep_sec(1);
 
 
-/*
-printf("loop\n");
-*/
 			continue;
 		}
 
-
 		task_timer[cpu] = get_xltime();
 		task_target[cpu] = t1;
 /*
@@ -1112,12 +1189,13 @@ log_printf(LOG_DEBUG,LOG_LAYER_GB,0,">>> %i %i\n",t1->type,get_tid());
 */
 /*
 if ( t1->filename )
-ss_printf(">>> %s %i %i\n",n_string(std_cm,t1->filename),t1->type,get_tid());
+ss_printf(">>> %i - %s %i %i\n",i,n_string(std_cm,t1->filename),t1->type,get_tid());
 else
-ss_printf(">>> %i %i\n",t1->type,get_tid());
+ss_printf(">>> %i - %i %i\n",i,t1->type,get_tid());
 */
 		gc_push(0,0,"acrp_task");
 		tt = new_mp_task_t();
+		tt->h.pri = i;
 		tt->tq = t1;
 
 
