@@ -53,6 +53,7 @@
 #define LL_VIMAGE	29
 #define LL_VOBJECT	30
 
+#define LL_SR		40
 #define LL_XLoHTTP	43
 #define LL_CHAIN	44
 #define LL_STREAM_THREAD 45
@@ -90,6 +91,7 @@
 #define LL_SETAGENT	270
 
 #define LL_PROGRESSIVE	275
+#define LL_SP		277
 
 #define LL_OBJ_MEM	280
 /*
