@@ -26,13 +26,16 @@
 #include	"lump.h"
 #include	"routing.h"
 
+//#define CACHE_TEST_DEBUG
+
 
 #define GB_NAMESPACE	"xlp://isjhp1.nichibun.ac.jp:8080/gb_metadata"
 #define RADAR_CACHE_SIZE		500
 #define RADAR_MATRIX_CACHE_SIZE		100
 #define RADAR_RECT_RATE			10
 #define RADAR_DOTS			500
-#define RADAR_DOTS_RATE			2
+//#define RADAR_DOTS_RATE			4
+#define RADAR_DOTS_RATE			20
 #define CLEAR_INTERVAL			50
 #define WIN_SURF_RATE_MIN		10
 #define WIN_SURF_RATE_MAX		11
@@ -339,6 +342,8 @@ typedef struct radar_cache {
 	char			retrieve_task1_active;
 	char			retrieve_task2_active;
 
+	char			search_rc_flag;
+	
 	unsigned		win_manage_task_req:1;
 	unsigned		loading_task_req:1;
 	unsigned		min_route_task_req:1;
@@ -549,7 +554,7 @@ void _delete_turning_loaded_reso(RADAR_MATRIX * mx,REAL1 lr);
 void _delete_node_from_crd(RADAR_CRD * c);
 void dump_radar_crd_list(RADAR_CACHE * rc_ptr);
 RADAR_CRD * new_radar_crd(RADAR_CACHE* rc_ptr);
-void flush_radar_crd(RADAR_CRD * c);
+void flush_radar_crd(RADAR_CACHE * ,RADAR_CRD * c);
 void _wait_radar_crd(RADAR_CRD * c);
 RADAR_CRD *
 search_radar_crd(RADAR_CACHE * rc_ptr,L_CHAR * crd,L_CHAR * obj,int wait_flag);
@@ -600,9 +605,9 @@ AVT_NODE * get_wf_tree(RADAR_CACHE * rc_ptr);
 int cmp_reso_sort(CRD_LIST * c1,CRD_LIST * c2);
 int reso_sort(AVT_NODE * a,AVT_NODE ** tree);
 RADAR_MATRIX_LIST *  get_parent(RADAR_MATRIX_LIST * lst);
-void _free_wf_tree(AVT_NODE * tree);
+void _free_wf_tree(RADAR_CACHE * ,AVT_NODE * tree);
 RADAR_MATRIX * _new_radar_matrix2(RADAR_CACHE * rc_ptr,Q_THREAD_LIST * qt,REAL1 reso,GB_RECT * r);
-int free_crd_lock(AVT_NODE * a);
+int free_crd_lock(AVT_NODE * a,void*);
 int h_limit_reso_func(AVT_NODE * a,HEURISTICS_PARAM * w);
 void h_search_limit_resolution(AVT_NODE * wf_tree,
 	HEURISTICS_PARAM * p);
@@ -788,7 +793,14 @@ rc_get_mouse_mode(RADAR_CACHE * rc_ptr,int * mode,I_POINT * ptr,INTEGER64 * tim,
 int
 rc_set_mouse_mode(RADAR_CACHE * rc_ptr,int mode,I_POINT ptr,INTEGER64 tim);
 
-
+void
+xx_wakeup_loading_task(RADAR_CACHE * rc_ptr,char * file,int line);
+void
+_xx_wakeup_loading_task(RADAR_CACHE * rc_ptr,char * file,int line);
+#define wakeup_loading_task(rc_ptr) xx_wakeup_loading_task(rc_ptr,__FILE__,__LINE__)
+#define _wakeup_loading_task(rc_ptr) _xx_wakeup_loading_task(rc_ptr,__FILE__,__LINE__)
+void _wakeup_win_manage(RADAR_CACHE *);
+void wakeup_win_manage(RADAR_CACHE *);
 
 #endif
 
