@@ -233,6 +233,9 @@ STREAM * st;
 XL_SEXP * encode;
 XL_SEXP * data;
 L_CHAR * dstr;
+
+
+//ss_printf("fd_initial_str\n");
 	if ( target == 0 ) {
 		data = (XL_SEXP*)_data;
 		_opt = (FD_STR_OPT*)opt;
@@ -249,7 +252,6 @@ L_CHAR * dstr;
 		else	_opt->convert = 0;
 		_opt->cm = cm;
 		_opt->h.merge_type = CH_TYPE_STRING;
-		
 		if ( list_length(data) == 3 )
 			_opt->h.init_sexp = get_el(data,2);
 		return 0;
@@ -266,7 +268,12 @@ L_CHAR * dstr;
 		}
 		else {
 			target->type = CH_STRING;
-			target->d.str = ln_copy_str(cm,dstr);
+			target->d.str = ln_copy_str(cm,code_convert_with_combine(
+					dstr,
+					l_strlen(dstr),
+					cm->main_code,
+					CBF_SRC_PLANE|CBF_DST_PLANE));
+//ss_printf("CONV = %s\n",target->d.str);
 		}
 	}
 	else {
@@ -285,19 +292,27 @@ L_CHAR * dstr;
 					data);
 				data = eval(env,_opt->convert);
 				if ( get_type(data) == XLT_ERROR ) {
+/*
 print_sexp(s_stdout,data,0);
 ss_printf("\n");
+*/
 					gc_pop(0,0);
 					return -1;
 				}
 			}
 			target->type = CH_STRING;
 			if ( get_type(data) == XLT_STRING ) {
-				target->d.str = ln_copy_str(cm,data->string.data);
+
+				target->d.str = ln_copy_str(cm,code_convert_with_combine(
+					data->string.data,
+					l_strlen(data->string.data),
+					cm->main_code,
+					CBF_SRC_PLANE|CBF_DST_PLANE));
+//ss_printf("CONV = %ls\n",target->d.str);
 			}
 			else {
 				st = s_open_string_write(cm);
-				print_sexp(st,data,0);
+				print_sexp(st,convert_code(data,cm->main_code,CBF_ERR_KEEP),0);
 				target->d.str = copy_str(s_get_string(st));
 				s_close(st);
 			}
