@@ -34,9 +34,11 @@ _main(int argc,char ** argv)
 {
 
 	init_xl(INI_DONTWAITCHI);
+	gc_push(0,0,"main");
 	init_function(gblisp_top_env0,gblisp_top_env1,argc,argv);
 	init_server_function(gblisp_top_env0,gblisp_top_env1);
 	init_sv_Exit(gblisp_top_env1);
+	gc_pop(0,0);
 
 	timeout_exit(
 		LIFETIME,
